/* strptime.h
 *
 * $Id: strptime.h,v 1.1 2005-07-16 17:02:10 robertl Exp $
 *
 * Ethereal - Network traffic analyzer
 * By Gerald Combs <gerald@ethereal.com>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef __STRPTIME_H__
#define __STRPTIME_H__

/*
 * Version of "strptime()", for the benefit of OSes that don't have it.
 */
#ifdef __cplusplus
extern "C" {
#endif
  extern char* strptime(const char*, const char*, struct tm*);
#ifdef __cplusplus
}
#endif
#endif

